# -*- makefile -*-
# octave-pkg.mk: CDBS-based debian/rules scrap for building/installing
#                octave-forge pkg add-ons
# This file is part of the octave-pkg-dev Debian package

# Copyright (c) 2008  Olafur Jens Sigurðsson <ojsbug@gmail.com>
# Copyright (c) 2008  Rafael Laboissiere <rafael@debian.org>
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along
# with this program; if not, write to the Free Software Foundation,
# Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.

include /usr/share/cdbs/1/rules/debhelper.mk

package = $(shell awk '/^Package:/ {print $$2; exit 0}' debian/control)
debpkg = debian/$(package)
shrpkg = /usr/share/octave/debian
mpath = usr/share/octave/packages
bpath = usr/lib/octave/packages
pkgname = $(package:octave-%=%)
hosttype = $(shell octave-config -p CANONICAL_HOST_TYPE)
apiversion = $(shell octave-config -p API_VERSION)
octave_options = --no-history --silent --no-init-file

install/$(package)::	\
	create-dirs	\
	install-pkg	\
	clean-files	\
	install-docs	\
	check-pkg	\
	remove-dirs

.PHONY: create-dirs
create-dirs:
	mkdir -p $(CURDIR)/$(debpkg)/$(mpath)	\
		 $(CURDIR)/$(debpkg)/$(bpath)

.PHONY: install-pkgs
install-pkg:
	-[ -e PKG_ADD ] && mv PKG_ADD PKG_ADD.bak
	octave3.0 $(octave_options) --eval			\
		"addpath ('$(shrpkg)/m', '-begin');		\
		 pkg ('prefix', [pwd(),'/$(debpkg)/$(mpath)'],	\
		      [pwd(),'/$(debpkg)/$(bpath)']);		\
		 pkg ('local_list', [pwd(),'.']);		\
		 pkg ('global_list', [pwd(),'.']);		\
		 if (glob ('PKG_ADD.bak')),			\
		     movefile ('PKG_ADD.bak', 'PKG_ADD');	\
		 endif;						\
		 pkg -verbose -nodeps install ."
	$(shrpkg)/dh/octave-pkg-helper
	dh_install --package=$(package)

.PHONY: clean-files
clean-files::
	( cd  $(shell find . -name packinfo) ; rm -f COPYING ChangeLog )

.PHONY: install-docs
install-docs:
	if [ -d doc ] ; then				\
		dh_installdocs -p$(package) doc/*;	\
		rm -rf $(debpkg)/$(mpath)/*/doc ;	\
	fi

.PHONY: check-pkg
ifeq (,$(findstring nocheck,$(DEB_BUILD_OPTIONS)))
check-pkg:
	-[ -e PKG_ADD ] && mv PKG_ADD PKG_ADD.bak

	@echo Checking package...

	@tmp=$$(tempfile) ;					\
	echo "addpath (genpath ([pwd(),'/debian']));" > $$tmp ;	\
	find debian/ -name \*.m					\
		| xargs grep -l '^%!\(assert\|test\)'		\
		| perl -pe 's:.*/(.*)\.m::;			\
			 print "disp (\"[$$1]\")\ntest $$1"'	\
		>> $$tmp ;					\
	octave3.0 $(octave_options) $$tmp ;			\
	rm -f $$tmp

	@if [ -f debian/check.m ] ; then			\
		octave3.0 $(octave_options) --eval		\
			"addpath (genpath ([pwd(),'/debian']));	\
			 source ('debian/check.m');" ;		\
	fi

	-[ -e PKG_ADD.bak ] && mv PKG_ADD.bak PKG_ADD
else
check-pkg:
endif

.PHONY: remove-dirs
remove-dirs:
	rmdir --ignore-fail-on-non-empty -p	\
		 $(CURDIR)/$(debpkg)/$(mpath)	\
		 $(CURDIR)/$(debpkg)/$(bpath)


DEB_MAKE_CLEAN_TARGET = -C src clean

clean::
ifneq ($(DEB_MAKE_CLEAN_TARGET),)
	-$(MAKE) -k $(DEB_MAKE_CLEAN_TARGET)
endif
	rm -rf inst/$(hosttype)-$(apiversion)
